InstalledIpRoutine

Struct InstalledIpRoutine 

pub struct InstalledIpRoutine {
    pub hook: Option<IpInstallationHook>,
    pub priority: Option<i32>,
    /* private fields */
}

Fields

hook: Option<IpInstallationHook>

The hook on which the routine is installed.

  • The INGRESS hook occurs for incoming traffic before a routing decision has been made.
  • The LOCAL_INGRESS hook occurs for incoming traffic that is destined for the local host.
  • The FORWARDING hook occurs for incoming traffic that is destined for another node.
  • The LOCAL_EGRESS hook occurs for locally-generated traffic before a final routing decision has been made.
  • The EGRESS hook occurs for all outgoing traffic after a routing decision has been made.

Required.

priority: Option<i32>

The priority of the routine relative to other routines installed on the same hook.

Interpreted as DEFAULT_ROUTINE_PRIORITY if unset.